@@ -2,7 +2,7 @@ package Date::Holidays::TW;
 use strict;
 use utf8;
 
-our $VERSION = v0.5.0;
+our $VERSION = v0.6.0;
 
 use Exporter 'import';
 our @EXPORT_OK = qw(is_tw_holiday tw_holidays);
@@ -1491,6 +1491,124 @@ my %CAL = (
         "1228" => "星期六、星期日",
         "1229" => "星期六、星期日",
     },
+
+    2025 => {
+        "0101" => "開國紀念日",
+        "0104" => "星期六、星期日",
+        "0105" => "星期六、星期日",
+        "0111" => "星期六、星期日",
+        "0112" => "星期六、星期日",
+        "0118" => "星期六、星期日",
+        "0119" => "星期六、星期日",
+        "0125" => "星期六、星期日",
+        "0126" => "星期六、星期日",
+        "0127" => "小年夜",
+        "0128" => "農曆除夕",
+        "0129" => "春節",
+        "0130" => "春節",
+        "0131" => "春節",
+        "0201" => "星期六、星期日",
+        "0202" => "星期六、星期日",
+        "0209" => "星期六、星期日",
+        "0215" => "星期六、星期日",
+        "0216" => "星期六、星期日",
+        "0222" => "星期六、星期日",
+        "0223" => "星期六、星期日",
+        "0228" => "和平紀念日",
+        "0301" => "星期六、星期日",
+        "0302" => "星期六、星期日",
+        "0308" => "星期六、星期日",
+        "0309" => "星期六、星期日",
+        "0315" => "星期六、星期日",
+        "0316" => "星期六、星期日",
+        "0322" => "星期六、星期日",
+        "0323" => "星期六、星期日",
+        "0329" => "星期六、星期日",
+        "0330" => "星期六、星期日",
+        "0403" => "補假",
+        "0404" => "兒童節及民族掃墓節",
+        "0405" => "星期六、星期日",
+        "0406" => "星期六、星期日",
+        "0412" => "星期六、星期日",
+        "0413" => "星期六、星期日",
+        "0419" => "星期六、星期日",
+        "0420" => "星期六、星期日",
+        "0426" => "星期六、星期日",
+        "0427" => "星期六、星期日",
+        "0503" => "星期六、星期日",
+        "0504" => "星期六、星期日",
+        "0510" => "星期六、星期日",
+        "0511" => "星期六、星期日",
+        "0517" => "星期六、星期日",
+        "0518" => "星期六、星期日",
+        "0524" => "星期六、星期日",
+        "0525" => "星期六、星期日",
+        "0530" => "補假",
+        "0531" => "端午節",
+        "0601" => "星期六、星期日",
+        "0607" => "星期六、星期日",
+        "0608" => "星期六、星期日",
+        "0614" => "星期六、星期日",
+        "0615" => "星期六、星期日",
+        "0621" => "星期六、星期日",
+        "0622" => "星期六、星期日",
+        "0628" => "星期六、星期日",
+        "0629" => "星期六、星期日",
+        "0705" => "星期六、星期日",
+        "0706" => "星期六、星期日",
+        "0712" => "星期六、星期日",
+        "0713" => "星期六、星期日",
+        "0719" => "星期六、星期日",
+        "0720" => "星期六、星期日",
+        "0726" => "星期六、星期日",
+        "0727" => "星期六、星期日",
+        "0802" => "星期六、星期日",
+        "0803" => "星期六、星期日",
+        "0809" => "星期六、星期日",
+        "0810" => "星期六、星期日",
+        "0816" => "星期六、星期日",
+        "0817" => "星期六、星期日",
+        "0823" => "星期六、星期日",
+        "0824" => "星期六、星期日",
+        "0830" => "星期六、星期日",
+        "0831" => "星期六、星期日",
+        "0906" => "星期六、星期日",
+        "0907" => "星期六、星期日",
+        "0913" => "星期六、星期日",
+        "0914" => "星期六、星期日",
+        "0920" => "星期六、星期日",
+        "0921" => "星期六、星期日",
+        "0927" => "星期六、星期日",
+        "0928" => "星期六、星期日",
+        "1004" => "星期六、星期日",
+        "1005" => "星期六、星期日",
+        "1006" => "中秋節",
+        "1010" => "國慶日",
+        "1011" => "星期六、星期日",
+        "1012" => "星期六、星期日",
+        "1018" => "星期六、星期日",
+        "1019" => "星期六、星期日",
+        "1025" => "星期六、星期日",
+        "1026" => "星期六、星期日",
+        "1101" => "星期六、星期日",
+        "1102" => "星期六、星期日",
+        "1108" => "星期六、星期日",
+        "1109" => "星期六、星期日",
+        "1115" => "星期六、星期日",
+        "1116" => "星期六、星期日",
+        "1122" => "星期六、星期日",
+        "1123" => "星期六、星期日",
+        "1129" => "星期六、星期日",
+        "1130" => "星期六、星期日",
+        "1206" => "星期六、星期日",
+        "1207" => "星期六、星期日",
+        "1213" => "星期六、星期日",
+        "1214" => "星期六、星期日",
+        "1220" => "星期六、星期日",
+        "1221" => "星期六、星期日",
+        "1227" => "星期六、星期日",
+        "1228" => "星期六、星期日",
+    },
 );
 
 sub new { bless {}, shift };
